@@ -16,6 +16,20 @@ impl<T, A: numeric_array::ArrayLength<T>> Size<T> for A {}
 /// Frames are used to transport audio data between `AudioNode` instances.
 pub type Frame<T, Size> = numeric_array::NumericArray<T, Size>;
 
+/// Tags are identified with parameters. Parameter values are always `f64`.
+pub type Tag = i64;
+
+/*
+Order of type arguments in nodes:
+1. Basic input and output arities excepting filter input selector arities.
+2. Interface float type.
+3. Processing float type.
+4. Unary or binary operation type.
+5. Filter input selector arity.
+6. Contained node types.
+7. The rest in any order.
+*/
+
 /// Generic audio processor.
 /// `AudioNode` has a static number of inputs (`AudioNode::Inputs`) and outputs (`AudioNode::Outputs`).
 /// `AudioNode` processes samples of type `AudioNode::Sample`, chosen statically.
@@ -64,7 +78,7 @@ pub trait AudioNode {
         }
     }
 
-    /// Set node hash. Override this to use the hash.
+    /// Set node pseudorandom phase hash. Override this to use the hash.
     /// This is called from `ping`. It should not be called by users.
     /// The default implementation does nothing.
     fn set_hash(&mut self, _hash: u64) {}
@@ -88,6 +102,15 @@ pub trait AudioNode {
         new_signal_frame(self.outputs())
     }
 
+    /// Set parameter value recursively. The default implementation does nothing.
+    fn set(&mut self, _parameter: Tag, _value: f64) {}
+
+    /// Query parameter value recursively. The first matching parameter is returned.
+    /// The default implementation returns `None`.
+    fn get(&self, _parameter: Tag) -> Option<f64> {
+        None
+    }
+
     // End of interface. There is no need to override the following.
 
     /// Number of inputs.
@@ -147,17 +170,17 @@ pub trait AudioNode {
 
 /// Pass through inputs unchanged.
 #[derive(Default)]
-pub struct MultiPass<T, N> {
-    _marker: PhantomData<(T, N)>,
+pub struct MultiPass<N, T> {
+    _marker: PhantomData<(N, T)>,
 }
 
-impl<T: Float, N: Size<T>> MultiPass<T, N> {
+impl<N: Size<T>, T: Float> MultiPass<N, T> {
     pub fn new() -> Self {
         MultiPass::default()
     }
 }
 
-impl<T: Float, N: Size<T>> AudioNode for MultiPass<T, N> {
+impl<N: Size<T>, T: Float> AudioNode for MultiPass<N, T> {
     const ID: u64 = 0;
     type Sample = T;
     type Inputs = N;
@@ -227,17 +250,17 @@ impl<T: Float> AudioNode for Pass<T> {
 
 /// Discard inputs.
 #[derive(Default)]
-pub struct Sink<T, N> {
-    _marker: PhantomData<(T, N)>,
+pub struct Sink<N, T> {
+    _marker: PhantomData<(N, T)>,
 }
 
-impl<T: Float, N: Size<T>> Sink<T, N> {
+impl<N: Size<T>, T: Float> Sink<N, T> {
     pub fn new() -> Self {
         Sink::default()
     }
 }
 
-impl<T: Float, N: Size<T>> AudioNode for Sink<T, N> {
+impl<N: Size<T>, T: Float> AudioNode for Sink<N, T> {
     const ID: u64 = 1;
     type Sample = T;
     type Inputs = N;
@@ -260,17 +283,26 @@ impl<T: Float, N: Size<T>> AudioNode for Sink<T, N> {
 }
 
 /// Output a constant value.
-pub struct Constant<T: Float, N: Size<T>> {
+pub struct Constant<N: Size<T>, T: Float> {
     output: Frame<T, N>,
 }
 
-impl<T: Float, N: Size<T>> Constant<T, N> {
+impl<N: Size<T>, T: Float> Constant<N, T> {
+    /// Construct constant.
     pub fn new(output: Frame<T, N>) -> Self {
         Constant { output }
     }
+    /// Set the value of the constant.
+    pub fn set_value(&mut self, output: Frame<T, N>) {
+        self.output = output;
+    }
+    /// Get the value of the constant.
+    pub fn value(&self) -> Frame<T, N> {
+        self.output.clone()
+    }
 }
 
-impl<T: Float, N: Size<T>> AudioNode for Constant<T, N> {
+impl<N: Size<T>, T: Float> AudioNode for Constant<N, T> {
     const ID: u64 = 2;
     type Sample = T;
     type Inputs = U0;
@@ -283,6 +315,7 @@ impl<T: Float, N: Size<T>> AudioNode for Constant<T, N> {
     ) -> Frame<Self::Sample, Self::Outputs> {
         self.output.clone()
     }
+
     fn process(
         &mut self,
         size: usize,
@@ -293,6 +326,7 @@ impl<T: Float, N: Size<T>> AudioNode for Constant<T, N> {
             output[i][..size].fill(self.output[i]);
         }
     }
+
     fn route(&self, _input: &SignalFrame, _frequency: f64) -> SignalFrame {
         let mut output = new_signal_frame(self.outputs());
         for i in 0..N::USIZE {
@@ -302,17 +336,82 @@ impl<T: Float, N: Size<T>> AudioNode for Constant<T, N> {
     }
 }
 
+/// Output a tagged constant.
+pub struct Tagged<T: Float> {
+    tag: Tag,
+    value: T,
+}
+
+impl<T: Float> Tagged<T> {
+    /// Construct constant whose value can be set and queried via the tag.
+    pub fn new(tag: Tag, value: T) -> Self {
+        Tagged { tag, value }
+    }
+    /// Set the value of the constant.
+    pub fn set_value(&mut self, value: T) {
+        self.value = value;
+    }
+    /// Get the value of the constant.
+    pub fn value(&self) -> T {
+        self.value
+    }
+}
+
+impl<T: Float> AudioNode for Tagged<T> {
+    const ID: u64 = 54;
+    type Sample = T;
+    type Inputs = U0;
+    type Outputs = U1;
+
+    #[inline]
+    fn tick(
+        &mut self,
+        _input: &Frame<Self::Sample, Self::Inputs>,
+    ) -> Frame<Self::Sample, Self::Outputs> {
+        [self.value].into()
+    }
+
+    fn process(
+        &mut self,
+        size: usize,
+        _input: &[&[Self::Sample]],
+        output: &mut [&mut [Self::Sample]],
+    ) {
+        output[0][..size].fill(self.value);
+    }
+
+    fn route(&self, _input: &SignalFrame, _frequency: f64) -> SignalFrame {
+        let mut output = new_signal_frame(self.outputs());
+        output[0] = Signal::Value(self.value.to_f64());
+        output
+    }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        if self.tag == parameter {
+            self.value = T::from_f64(value);
+        }
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        if self.tag == parameter {
+            Some(self.value.to_f64())
+        } else {
+            None
+        }
+    }
+}
+
 /// Split input into `N` channels.
-pub struct Split<T, N> {
-    _marker: PhantomData<(T, N)>,
+pub struct Split<N, T> {
+    _marker: PhantomData<(N, T)>,
 }
 
 // Note. We have separate split and multisplit (and join and multijoin)
 // implementations because it helps with type inference.
-impl<T, N> Split<T, N>
+impl<N, T> Split<N, T>
 where
-    T: Float,
     N: Size<T>,
+    T: Float,
 {
     #[allow(clippy::new_without_default)]
     pub fn new() -> Self {
@@ -322,10 +421,10 @@ where
     }
 }
 
-impl<T, N> AudioNode for Split<T, N>
+impl<N, T> AudioNode for Split<N, T>
 where
-    T: Float,
     N: Size<T>,
+    T: Float,
 {
     const ID: u64 = 40;
     type Sample = T;
@@ -339,22 +438,32 @@ where
     ) -> Frame<Self::Sample, Self::Outputs> {
         Frame::splat(input[0])
     }
+    fn process(
+        &mut self,
+        size: usize,
+        input: &[&[Self::Sample]],
+        output: &mut [&mut [Self::Sample]],
+    ) {
+        for channel in 0..N::USIZE {
+            output[channel][..size].clone_from_slice(&input[0][..size]);
+        }
+    }
     fn route(&self, input: &SignalFrame, _frequency: f64) -> SignalFrame {
         Routing::Split.propagate(input, self.outputs())
     }
 }
 
 /// Split `M` inputs into `N` branches, with `M` * `N` outputs.
-pub struct MultiSplit<T, M, N> {
-    _marker: PhantomData<(T, M, N)>,
+pub struct MultiSplit<M, N, T> {
+    _marker: PhantomData<(M, N, T)>,
 }
 
-impl<T, M, N> MultiSplit<T, M, N>
+impl<M, N, T> MultiSplit<M, N, T>
 where
-    T: Float,
     M: Size<T> + Mul<N>,
     N: Size<T>,
     <M as Mul<N>>::Output: Size<T>,
+    T: Float,
 {
     #[allow(clippy::new_without_default)]
     pub fn new() -> Self {
@@ -364,12 +473,12 @@ where
     }
 }
 
-impl<T, M, N> AudioNode for MultiSplit<T, M, N>
+impl<M, N, T> AudioNode for MultiSplit<M, N, T>
 where
-    T: Float,
     M: Size<T> + Mul<N>,
     N: Size<T>,
     <M as Mul<N>>::Output: Size<T>,
+    T: Float,
 {
     const ID: u64 = 38;
     type Sample = T;
@@ -383,20 +492,30 @@ where
     ) -> Frame<Self::Sample, Self::Outputs> {
         Frame::generate(|i| input[i % M::USIZE])
     }
+    fn process(
+        &mut self,
+        size: usize,
+        input: &[&[Self::Sample]],
+        output: &mut [&mut [Self::Sample]],
+    ) {
+        for channel in 0..M::USIZE * N::USIZE {
+            output[channel][..size].clone_from_slice(&input[channel % M::USIZE][..size]);
+        }
+    }
     fn route(&self, input: &SignalFrame, _frequency: f64) -> SignalFrame {
         Routing::Split.propagate(input, self.outputs())
     }
 }
 
 /// Join `N` channels into one by averaging. Inverse of `Split<T, N>`.
-pub struct Join<T, N> {
-    _marker: PhantomData<(T, N)>,
+pub struct Join<N, T> {
+    _marker: PhantomData<(N, T)>,
 }
 
-impl<T, N> Join<T, N>
+impl<N, T> Join<N, T>
 where
-    T: Float,
     N: Size<T>,
+    T: Float,
 {
     #[allow(clippy::new_without_default)]
     pub fn new() -> Self {
@@ -406,10 +525,10 @@ where
     }
 }
 
-impl<T, N> AudioNode for Join<T, N>
+impl<N, T> AudioNode for Join<N, T>
 where
-    T: Float,
     N: Size<T>,
+    T: Float,
 {
     const ID: u64 = 41;
     type Sample = T;
@@ -427,7 +546,22 @@ where
         }
         [output / T::new(N::I64)].into()
     }
-
+    fn process(
+        &mut self,
+        size: usize,
+        input: &[&[Self::Sample]],
+        output: &mut [&mut [Self::Sample]],
+    ) {
+        let z = T::one() / T::new(N::I64);
+        for i in 0..size {
+            output[0][i] = input[0][i] * z;
+        }
+        for channel in 1..N::USIZE {
+            for i in 0..size {
+                output[channel][i] += input[channel][i] * z;
+            }
+        }
+    }
     fn route(&self, input: &SignalFrame, _frequency: f64) -> SignalFrame {
         Routing::Join.propagate(input, self.outputs())
     }
@@ -435,16 +569,16 @@ where
 
 /// Average `N` branches of `M` channels into one branch with `M` channels.
 /// The input has `M` * `N` channels. Inverse of `MultiSplit<T, M, N>`.
-pub struct MultiJoin<T, M, N> {
-    _marker: PhantomData<(T, M, N)>,
+pub struct MultiJoin<M, N, T> {
+    _marker: PhantomData<(M, N, T)>,
 }
 
-impl<T, M, N> MultiJoin<T, M, N>
+impl<M, N, T> MultiJoin<M, N, T>
 where
-    T: Float,
     M: Size<T> + Mul<N>,
     N: Size<T>,
     <M as Mul<N>>::Output: Size<T>,
+    T: Float,
 {
     #[allow(clippy::new_without_default)]
     pub fn new() -> Self {
@@ -454,12 +588,12 @@ where
     }
 }
 
-impl<T, M, N> AudioNode for MultiJoin<T, M, N>
+impl<M, N, T> AudioNode for MultiJoin<M, N, T>
 where
-    T: Float,
     M: Size<T> + Mul<N>,
     N: Size<T>,
     <M as Mul<N>>::Output: Size<T>,
+    T: Float,
 {
     const ID: u64 = 39;
     type Sample = T;
@@ -479,14 +613,31 @@ where
             output / T::new(N::I64)
         })
     }
-
+    fn process(
+        &mut self,
+        size: usize,
+        input: &[&[Self::Sample]],
+        output: &mut [&mut [Self::Sample]],
+    ) {
+        let z = T::one() / T::new(N::I64);
+        for channel in 0..M::USIZE {
+            for i in 0..size {
+                output[channel][i] = input[channel][i] * z;
+            }
+        }
+        for channel in M::USIZE..M::USIZE * N::USIZE {
+            for i in 0..size {
+                output[channel % M::USIZE][i] += input[channel][i] * z;
+            }
+        }
+    }
     fn route(&self, input: &SignalFrame, _frequency: f64) -> SignalFrame {
         Routing::Join.propagate(input, self.outputs())
     }
 }
 
 /// Provides binary operator implementations to the `Binop` node.
-pub trait FrameBinop<T: Float, N: Size<T>> {
+pub trait FrameBinop<N: Size<T>, T: Float> {
     /// Do binary op (x op y) channelwise.
     fn binop(x: &Frame<T, N>, y: &Frame<T, N>) -> Frame<T, N>;
     /// Do binary op (x op y) on signals.
@@ -497,17 +648,17 @@ pub trait FrameBinop<T: Float, N: Size<T>> {
 
 /// Addition operator.
 #[derive(Default)]
-pub struct FrameAdd<T: Float, N: Size<T>> {
-    _marker: PhantomData<(T, N)>,
+pub struct FrameAdd<N: Size<T>, T: Float> {
+    _marker: PhantomData<(N, T)>,
 }
 
-impl<T: Float, N: Size<T>> FrameAdd<T, N> {
-    pub fn new() -> FrameAdd<T, N> {
+impl<N: Size<T>, T: Float> FrameAdd<N, T> {
+    pub fn new() -> FrameAdd<N, T> {
         FrameAdd::default()
     }
 }
 
-impl<T: Float, N: Size<T>> FrameBinop<T, N> for FrameAdd<T, N> {
+impl<N: Size<T>, T: Float> FrameBinop<N, T> for FrameAdd<N, T> {
     #[inline]
     fn binop(x: &Frame<T, N>, y: &Frame<T, N>) -> Frame<T, N> {
         x + y
@@ -525,17 +676,17 @@ impl<T: Float, N: Size<T>> FrameBinop<T, N> for FrameAdd<T, N> {
 
 /// Subtraction operator.
 #[derive(Default)]
-pub struct FrameSub<T: Float, N: Size<T>> {
-    _marker: PhantomData<(T, N)>,
+pub struct FrameSub<N: Size<T>, T: Float> {
+    _marker: PhantomData<(N, T)>,
 }
 
-impl<T: Float, N: Size<T>> FrameSub<T, N> {
-    pub fn new() -> FrameSub<T, N> {
+impl<N: Size<T>, T: Float> FrameSub<N, T> {
+    pub fn new() -> FrameSub<N, T> {
         FrameSub::default()
     }
 }
 
-impl<T: Float, N: Size<T>> FrameBinop<T, N> for FrameSub<T, N> {
+impl<N: Size<T>, T: Float> FrameBinop<N, T> for FrameSub<N, T> {
     #[inline]
     fn binop(x: &Frame<T, N>, y: &Frame<T, N>) -> Frame<T, N> {
         x - y
@@ -553,17 +704,17 @@ impl<T: Float, N: Size<T>> FrameBinop<T, N> for FrameSub<T, N> {
 
 /// Multiplication operator.
 #[derive(Default)]
-pub struct FrameMul<T: Float, N: Size<T>> {
-    _marker: PhantomData<(T, N)>,
+pub struct FrameMul<N: Size<T>, T: Float> {
+    _marker: PhantomData<(N, T)>,
 }
 
-impl<T: Float, N: Size<T>> FrameMul<T, N> {
-    pub fn new() -> FrameMul<T, N> {
+impl<N: Size<T>, T: Float> FrameMul<N, T> {
+    pub fn new() -> FrameMul<N, T> {
         FrameMul::default()
     }
 }
 
-impl<T: Float, N: Size<T>> FrameBinop<T, N> for FrameMul<T, N> {
+impl<N: Size<T>, T: Float> FrameBinop<N, T> for FrameMul<N, T> {
     #[inline]
     fn binop(x: &Frame<T, N>, y: &Frame<T, N>) -> Frame<T, N> {
         x * y
@@ -617,7 +768,7 @@ where
     T: Float,
     X: AudioNode<Sample = T>,
     Y: AudioNode<Sample = T, Outputs = X::Outputs>,
-    B: FrameBinop<T, X::Outputs>,
+    B: FrameBinop<X::Outputs, T>,
     X::Inputs: Size<T> + Add<Y::Inputs>,
     X::Outputs: Size<T>,
     Y::Inputs: Size<T>,
@@ -662,7 +813,7 @@ where
     T: Float,
     X: AudioNode<Sample = T>,
     Y: AudioNode<Sample = T, Outputs = X::Outputs>,
-    B: FrameBinop<T, X::Outputs>,
+    B: FrameBinop<X::Outputs, T>,
     X::Outputs: Size<T>,
     X::Inputs: Size<T> + Add<Y::Inputs>,
     Y::Inputs: Size<T>,
@@ -720,10 +871,19 @@ where
         }
         signal_x
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        self.x.set(parameter, value);
+        self.y.set(parameter, value);
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        self.x.get(parameter).or_else(|| self.y.get(parameter))
+    }
 }
 
 /// Provides unary operator implementations to the `Unop` node.
-pub trait FrameUnop<T: Float, N: Size<T>> {
+pub trait FrameUnop<N: Size<T>, T: Float> {
     /// Do unary op channelwise.
     fn unop(x: &Frame<T, N>) -> Frame<T, N>;
     /// Do unary op on signal.
@@ -734,17 +894,17 @@ pub trait FrameUnop<T: Float, N: Size<T>> {
 
 /// Negation operator.
 #[derive(Default)]
-pub struct FrameNeg<T: Float, N: Size<T>> {
-    _marker: PhantomData<(T, N)>,
+pub struct FrameNeg<N: Size<T>, T: Float> {
+    _marker: PhantomData<(N, T)>,
 }
 
-impl<T: Float, N: Size<T>> FrameNeg<T, N> {
-    pub fn new() -> FrameNeg<T, N> {
+impl<N: Size<T>, T: Float> FrameNeg<N, T> {
+    pub fn new() -> FrameNeg<N, T> {
         FrameNeg::default()
     }
 }
 
-impl<T: Float, N: Size<T>> FrameUnop<T, N> for FrameNeg<T, N> {
+impl<N: Size<T>, T: Float> FrameUnop<N, T> for FrameNeg<N, T> {
     #[inline]
     fn unop(x: &Frame<T, N>) -> Frame<T, N> {
         -x
@@ -766,17 +926,17 @@ impl<T: Float, N: Size<T>> FrameUnop<T, N> for FrameNeg<T, N> {
 
 /// Identity op.
 #[derive(Default)]
-pub struct FrameId<T: Float, N: Size<T>> {
-    _marker: PhantomData<(T, N)>,
+pub struct FrameId<N: Size<T>, T: Float> {
+    _marker: PhantomData<(N, T)>,
 }
 
-impl<T: Float, N: Size<T>> FrameId<T, N> {
-    pub fn new() -> FrameId<T, N> {
+impl<N: Size<T>, T: Float> FrameId<N, T> {
+    pub fn new() -> FrameId<N, T> {
         FrameId::default()
     }
 }
 
-impl<T: Float, N: Size<T>> FrameUnop<T, N> for FrameId<T, N> {
+impl<N: Size<T>, T: Float> FrameUnop<N, T> for FrameId<N, T> {
     #[inline]
     fn unop(x: &Frame<T, N>) -> Frame<T, N> {
         x.clone()
@@ -800,7 +960,7 @@ impl<T, X, U> Unop<T, X, U>
 where
     T: Float,
     X: AudioNode<Sample = T>,
-    U: FrameUnop<T, X::Outputs>,
+    U: FrameUnop<X::Outputs, T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T>,
 {
@@ -820,7 +980,7 @@ impl<T, X, U> AudioNode for Unop<T, X, U>
 where
     T: Float,
     X: AudioNode<Sample = T>,
-    U: FrameUnop<T, X::Outputs>,
+    U: FrameUnop<X::Outputs, T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T>,
 {
@@ -862,6 +1022,14 @@ where
         }
         signal_x
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        self.x.set(parameter, value);
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        self.x.get(parameter)
+    }
 }
 
 /// Map any number of channels.
@@ -983,6 +1151,7 @@ where
         self.x.reset(sample_rate);
         self.y.reset(sample_rate);
     }
+
     #[inline]
     fn tick(
         &mut self,
@@ -990,6 +1159,7 @@ where
     ) -> Frame<Self::Sample, Self::Outputs> {
         self.y.tick(&self.x.tick(input))
     }
+
     fn process(
         &mut self,
         size: usize,
@@ -1001,13 +1171,23 @@ where
         self.y
             .process(size, self.buffer.get_ref(self.y.inputs()), output);
     }
-    #[inline]
+
     fn ping(&mut self, probe: bool, hash: AttoRand) -> AttoRand {
         self.y.ping(probe, self.x.ping(probe, hash.hash(Self::ID)))
     }
+
     fn route(&self, input: &SignalFrame, frequency: f64) -> SignalFrame {
         self.y.route(&self.x.route(input, frequency), frequency)
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        self.x.set(parameter, value);
+        self.y.set(parameter, value);
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        self.x.get(parameter).or_else(|| self.y.get(parameter))
+    }
 }
 
 /// Stack `X` and `Y` in parallel.
@@ -1116,7 +1296,7 @@ where
             &mut output[X::Outputs::USIZE..],
         );
     }
-    #[inline]
+
     fn ping(&mut self, probe: bool, hash: AttoRand) -> AttoRand {
         self.y.ping(probe, self.x.ping(probe, hash.hash(Self::ID)))
     }
@@ -1132,6 +1312,15 @@ where
             .copy_from_slice(&signal_y[0..Y::Outputs::USIZE]);
         signal_x
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        self.x.set(parameter, value);
+        self.y.set(parameter, value);
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        self.x.get(parameter).or_else(|| self.y.get(parameter))
+    }
 }
 
 /// Send the same input to `X` and `Y`. Concatenate outputs.
@@ -1241,6 +1430,15 @@ where
             .copy_from_slice(&signal_y[0..Y::Outputs::USIZE]);
         signal_x
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        self.x.set(parameter, value);
+        self.y.set(parameter, value);
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        self.x.get(parameter).or_else(|| self.y.get(parameter))
+    }
 }
 
 /// Mix together `X` and `Y` sourcing from the same inputs.
@@ -1316,6 +1514,7 @@ where
         self.x.reset(sample_rate);
         self.y.reset(sample_rate);
     }
+
     #[inline]
     fn tick(
         &mut self,
@@ -1325,6 +1524,7 @@ where
         let output_y = self.y.tick(input);
         output_x + output_y
     }
+
     fn process(
         &mut self,
         size: usize,
@@ -1342,7 +1542,7 @@ where
             }
         }
     }
-    #[inline]
+
     fn ping(&mut self, probe: bool, hash: AttoRand) -> AttoRand {
         self.y.ping(probe, self.x.ping(probe, hash.hash(Self::ID)))
     }
@@ -1355,6 +1555,15 @@ where
         }
         signal_x
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        self.x.set(parameter, value);
+        self.y.set(parameter, value);
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        self.x.get(parameter).or_else(|| self.y.get(parameter))
+    }
 }
 
 /// Pass through inputs without matching outputs.
@@ -1439,14 +1648,22 @@ impl<X: AudioNode> AudioNode for Thru<X> {
             .copy_from_slice(&input[X::Outputs::USIZE..Self::Outputs::USIZE]);
         output
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        self.x.set(parameter, value);
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        self.x.get(parameter)
+    }
 }
 
 /// Mix together a bunch of similar nodes sourcing from the same inputs.
-pub struct MultiBus<T, N, X>
+pub struct MultiBus<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T>,
@@ -1456,11 +1673,11 @@ where
     buffer: Buffer<T>,
 }
 
-impl<T, N, X> MultiBus<T, N, X>
+impl<N, T, X> MultiBus<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T>,
@@ -1487,11 +1704,11 @@ where
     }
 }
 
-impl<T, N, X> AudioNode for MultiBus<T, N, X>
+impl<N, T, X> AudioNode for MultiBus<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T>,
@@ -1558,29 +1775,44 @@ where
         }
         output
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        for x in self.x.iter_mut() {
+            x.set(parameter, value);
+        }
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        for x in self.x.iter() {
+            if let Some(value) = x.get(parameter) {
+                return Some(value);
+            }
+        }
+        None
+    }
 }
 
 /// Stack a bunch of similar nodes in parallel.
-pub struct MultiStack<T, N, X>
+pub struct MultiStack<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T> + Mul<N>,
     X::Outputs: Size<T> + Mul<N>,
     <X::Inputs as Mul<N>>::Output: Size<T>,
     <X::Outputs as Mul<N>>::Output: Size<T>,
 {
-    _marker: PhantomData<(T, N)>,
+    _marker: PhantomData<(N, T)>,
     x: Frame<X, N>,
 }
 
-impl<T, N, X> MultiStack<T, N, X>
+impl<N, T, X> MultiStack<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T> + Mul<N>,
     X::Outputs: Size<T> + Mul<N>,
@@ -1608,11 +1840,11 @@ where
     }
 }
 
-impl<T, N, X> AudioNode for MultiStack<T, N, X>
+impl<N, T, X> AudioNode for MultiStack<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T> + Mul<N>,
     X::Outputs: Size<T> + Mul<N>,
@@ -1686,21 +1918,36 @@ where
         }
         output
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        for x in self.x.iter_mut() {
+            x.set(parameter, value);
+        }
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        for x in self.x.iter() {
+            if let Some(value) = x.get(parameter) {
+                return Some(value);
+            }
+        }
+        None
+    }
 }
 
 /// Combine outputs of a bunch of similar nodes with a binary operation.
 /// Inputs are disjoint.
 /// Outputs are combined channel-wise.
-pub struct Reduce<T, N, X, B>
+pub struct Reduce<N, T, X, B>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T> + Mul<N>,
     X::Outputs: Size<T>,
     <X::Inputs as Mul<N>>::Output: Size<T>,
-    B: FrameBinop<T, X::Outputs>,
+    B: FrameBinop<X::Outputs, T>,
 {
     x: Frame<X, N>,
     #[allow(dead_code)]
@@ -1709,16 +1956,16 @@ where
     _marker: PhantomData<T>,
 }
 
-impl<T, N, X, B> Reduce<T, N, X, B>
+impl<N, T, X, B> Reduce<N, T, X, B>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T> + Mul<N>,
     X::Outputs: Size<T>,
     <X::Inputs as Mul<N>>::Output: Size<T>,
-    B: FrameBinop<T, X::Outputs>,
+    B: FrameBinop<X::Outputs, T>,
 {
     pub fn new(x: Frame<X, N>, b: B) -> Self {
         let mut node = Reduce {
@@ -1743,16 +1990,16 @@ where
     }
 }
 
-impl<T, N, X, B> AudioNode for Reduce<T, N, X, B>
+impl<N, T, X, B> AudioNode for Reduce<N, T, X, B>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T> + Mul<N>,
     X::Outputs: Size<T>,
     <X::Inputs as Mul<N>>::Output: Size<T>,
-    B: FrameBinop<T, X::Outputs>,
+    B: FrameBinop<X::Outputs, T>,
 {
     const ID: u64 = 32;
     type Sample = T;
@@ -1825,14 +2072,29 @@ where
         }
         output
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        for x in self.x.iter_mut() {
+            x.set(parameter, value);
+        }
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        for x in self.x.iter() {
+            if let Some(value) = x.get(parameter) {
+                return Some(value);
+            }
+        }
+        None
+    }
 }
 
 /// Branch into a bunch of similar nodes in parallel.
-pub struct MultiBranch<T, N, X>
+pub struct MultiBranch<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T> + Mul<N>,
@@ -1842,11 +2104,11 @@ where
     x: Frame<X, N>,
 }
 
-impl<T, N, X> MultiBranch<T, N, X>
+impl<N, T, X> MultiBranch<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T> + Mul<N>,
@@ -1873,11 +2135,11 @@ where
     }
 }
 
-impl<T, N, X> AudioNode for MultiBranch<T, N, X>
+impl<N, T, X> AudioNode for MultiBranch<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T> + Mul<N>,
@@ -1917,7 +2179,7 @@ where
             out_channel = next_out_channel;
         }
     }
-    #[inline]
+
     fn ping(&mut self, probe: bool, hash: AttoRand) -> AttoRand {
         let mut hash = hash.hash(Self::ID);
         for x in self.x.iter_mut() {
@@ -1939,14 +2201,29 @@ where
         }
         output
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        for x in self.x.iter_mut() {
+            x.set(parameter, value);
+        }
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        for x in self.x.iter() {
+            if let Some(value) = x.get(parameter) {
+                return Some(value);
+            }
+        }
+        None
+    }
 }
 
 /// Chain together a bunch of similar nodes.
-pub struct Chain<T, N, X>
+pub struct Chain<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T>,
@@ -1957,11 +2234,11 @@ where
     _marker: PhantomData<T>,
 }
 
-impl<T, N, X> Chain<T, N, X>
+impl<N, T, X> Chain<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T>,
@@ -1989,11 +2266,11 @@ where
     }
 }
 
-impl<T, N, X> AudioNode for Chain<T, N, X>
+impl<N, T, X> AudioNode for Chain<N, T, X>
 where
-    T: Float,
     N: Size<T>,
     N: Size<X>,
+    T: Float,
     X: AudioNode<Sample = T>,
     X::Inputs: Size<T>,
     X::Outputs: Size<T>,
@@ -2059,7 +2336,7 @@ where
             }
         }
     }
-    #[inline]
+
     fn ping(&mut self, probe: bool, hash: AttoRand) -> AttoRand {
         let mut hash = hash.hash(Self::ID);
         for x in self.x.iter_mut() {
@@ -2075,6 +2352,21 @@ where
         }
         output
     }
+
+    fn set(&mut self, parameter: Tag, value: f64) {
+        for x in self.x.iter_mut() {
+            x.set(parameter, value);
+        }
+    }
+
+    fn get(&self, parameter: Tag) -> Option<f64> {
+        for x in self.x.iter() {
+            if let Some(value) = x.get(parameter) {
+                return Some(value);
+            }
+        }
+        None
+    }
 }
 
 /// Swap stereo channels.
