@@ -217,7 +217,6 @@ where
         let mut output = new_signal_frame(self.outputs());
         for i in 0..N::USIZE {
             // We pretend that the limiter does not alter the frequency response.
-            // TODO. Is this really the best option.
             output[i] = input[i].delay(self.reducer.length() as f64);
         }
         output
@@ -226,32 +225,32 @@ where
 
 /// Goertzel frequency detector.
 #[derive(Clone, Default)]
-pub struct Detector<F: Real> {
-    y1: F,
-    y2: F,
-    ccoeff: F,
-    scoeff: F,
+pub struct Detector<T: Real> {
+    y1: T,
+    y2: T,
+    ccoeff: T,
+    scoeff: T,
 }
-impl<F: Real> Detector<F> {
+impl<T: Real> Detector<T> {
     /// Reset detector.
     pub fn reset(&mut self) {
-        self.y1 = F::zero();
-        self.y2 = F::zero();
+        self.y1 = T::zero();
+        self.y2 = T::zero();
     }
     /// Select the frequency (in Hz).
-    pub fn set_frequency(&mut self, sample_rate: F, frequency: F) {
-        let f = F::from_f64(TAU) * frequency / sample_rate;
-        self.ccoeff = F::new(2) * cos(f);
+    pub fn set_frequency(&mut self, sample_rate: T, frequency: T) {
+        let f = T::from_f64(TAU) * frequency / sample_rate;
+        self.ccoeff = T::new(2) * cos(f);
         self.scoeff = sin(f);
     }
     /// Process one sample.
-    pub fn tick(&mut self, x: F) {
+    pub fn tick(&mut self, x: T) {
         let y0 = x + self.ccoeff * self.y1 - self.y2;
         self.y2 = self.y1;
         self.y1 = y0;
     }
     /// Current detected power at the selected frequency.
-    pub fn power(&self) -> F {
+    pub fn power(&self) -> T {
         squared(self.y2) + squared(self.y1) - self.ccoeff * self.y2 * self.y1
     }
 }
@@ -289,7 +288,6 @@ impl<T: Float, F: Real> AudioNode for Goertzel<T, F> {
         self.filter.reset();
         if let Some(sample_rate) = sample_rate {
             self.sample_rate = F::from_f64(sample_rate);
-            // TODO: Remain in a valid state?
             self.frequency = F::zero();
         }
     }
@@ -365,6 +363,30 @@ impl<T: Float, F: Real> AudioNode for Declick<T, F> {
         }
     }
 
+    fn process(
+        &mut self,
+        size: usize,
+        input: &[&[Self::Sample]],
+        output: &mut [&mut [Self::Sample]],
+    ) {
+        output[0][..size].clone_from_slice(&input[0][..size]);
+        if self.t < self.duration {
+            let mut phase = delerp(F::zero(), self.duration, self.t);
+            let phase_d = self.sample_duration / self.duration;
+            let end_time = self.t + F::new(size as i64) * self.sample_duration;
+            let end_index = if self.duration < end_time {
+                round((self.duration - self.t) / self.sample_duration).to_i64() as usize
+            } else {
+                size
+            };
+            for i in 0..end_index {
+                output[0][i] *= convert(smooth5(phase));
+                phase += phase_d;
+            }
+            self.t = end_time;
+        }
+    }
+
     fn route(&self, input: &SignalFrame, _frequency: f64) -> SignalFrame {
         let mut output = new_signal_frame(self.outputs());
         // We pretend that the declicker does not alter frequency response.
