@@ -8,9 +8,12 @@ pub use super::dynamics::*;
 pub use super::envelope::*;
 pub use super::feedback::*;
 pub use super::filter::*;
+pub use super::fir::*;
 pub use super::math::*;
 pub use super::noise::*;
 pub use super::oscillator::*;
+pub use super::oversample::*;
+pub use super::pan::*;
 pub use super::sequencer::*;
 pub use super::shape::*;
 pub use super::signal::*;
@@ -126,11 +129,39 @@ pub type U97 = numeric_array::typenum::U97;
 pub type U98 = numeric_array::typenum::U98;
 pub type U99 = numeric_array::typenum::U99;
 pub type U100 = numeric_array::typenum::U100;
+pub type U101 = numeric_array::typenum::U101;
+pub type U102 = numeric_array::typenum::U102;
+pub type U103 = numeric_array::typenum::U103;
+pub type U104 = numeric_array::typenum::U104;
+pub type U105 = numeric_array::typenum::U105;
+pub type U106 = numeric_array::typenum::U106;
+pub type U107 = numeric_array::typenum::U107;
+pub type U108 = numeric_array::typenum::U108;
+pub type U109 = numeric_array::typenum::U109;
+pub type U110 = numeric_array::typenum::U110;
+pub type U111 = numeric_array::typenum::U111;
+pub type U112 = numeric_array::typenum::U112;
+pub type U113 = numeric_array::typenum::U113;
+pub type U114 = numeric_array::typenum::U114;
+pub type U115 = numeric_array::typenum::U115;
+pub type U116 = numeric_array::typenum::U116;
+pub type U117 = numeric_array::typenum::U117;
+pub type U118 = numeric_array::typenum::U118;
+pub type U119 = numeric_array::typenum::U119;
+pub type U120 = numeric_array::typenum::U120;
+pub type U121 = numeric_array::typenum::U121;
+pub type U122 = numeric_array::typenum::U122;
+pub type U123 = numeric_array::typenum::U123;
+pub type U124 = numeric_array::typenum::U124;
+pub type U125 = numeric_array::typenum::U125;
+pub type U126 = numeric_array::typenum::U126;
+pub type U127 = numeric_array::typenum::U127;
+pub type U128 = numeric_array::typenum::U128;
 
 /// Constant node.
 /// Synonymous with `[dc]`.
 #[inline]
-pub fn constant<X: ConstantFrame<Sample = f64>>(x: X) -> An<Constant<f64, X::Size>>
+pub fn constant<X: ConstantFrame<Sample = f64>>(x: X) -> An<Constant<X::Size, f64>>
 where
     X::Size: Size<f64>,
 {
@@ -141,24 +172,31 @@ where
 /// Synonymous with `constant`.
 /// (DC stands for "direct current", which is an electrical engineering term used with signals.)
 #[inline]
-pub fn dc<X: ConstantFrame<Sample = f64>>(x: X) -> An<Constant<f64, X::Size>>
+pub fn dc<X: ConstantFrame<Sample = f64>>(x: X) -> An<Constant<X::Size, f64>>
 where
     X::Size: Size<f64>,
 {
     An(Constant::new(x.convert()))
 }
 
+/// Tagged constant. Outputs the (scalar) value of the tag.
+/// - Output 0: value
+#[inline]
+pub fn tag(tag: Tag, value: f64) -> An<Tagged<f64>> {
+    An(Tagged::new(tag, value))
+}
+
 /// Zero generator.
 /// - Output 0: zero
 #[inline]
-pub fn zero() -> An<Constant<f64, U1>> {
+pub fn zero() -> An<Constant<U1, f64>> {
     constant(0.0)
 }
 
 /// Multichannel zero generator.
 /// - Output(s): zero
 #[inline]
-pub fn multizero<U: Size<f64>>() -> An<Constant<f64, U>> {
+pub fn multizero<N: Size<f64>>() -> An<Constant<N, f64>> {
     An(Constant::new(Frame::splat(0.0)))
 }
 
@@ -170,19 +208,19 @@ pub fn pass() -> An<Pass<f64>> {
 
 /// Multichannel pass-through.
 #[inline]
-pub fn multipass<U: Size<f64>>() -> An<MultiPass<f64, U>> {
+pub fn multipass<N: Size<f64>>() -> An<MultiPass<N, f64>> {
     An(MultiPass::new())
 }
 
 /// Mono sink. Input is discarded.
 #[inline]
-pub fn sink() -> An<Sink<f64, U1>> {
+pub fn sink() -> An<Sink<U1, f64>> {
     An(Sink::new())
 }
 
 /// Multichannel sink. Inputs are discarded.
 #[inline]
-pub fn multisink<U: Size<f64>>() -> An<Sink<f64, U>> {
+pub fn multisink<N: Size<f64>>() -> An<Sink<N, f64>> {
     An(Sink::new())
 }
 
@@ -207,7 +245,7 @@ pub fn sine() -> An<Sine<f64>> {
 /// Fixed sine oscillator at `f` Hz.
 /// - Output 0: sine wave
 #[inline]
-pub fn sine_hz(f: f64) -> An<Pipe<f64, Constant<f64, U1>, Sine<f64>>> {
+pub fn sine_hz(f: f64) -> An<Pipe<f64, Constant<U1, f64>, Sine<f64>>> {
     super::prelude::sine_hz(f)
 }
 
@@ -215,36 +253,36 @@ pub fn sine_hz(f: f64) -> An<Pipe<f64, Constant<f64, U1>, Sine<f64>>> {
 #[inline]
 pub fn add<X: ConstantFrame<Sample = f64>>(
     x: X,
-) -> An<Binop<f64, FrameAdd<f64, X::Size>, MultiPass<f64, X::Size>, Constant<f64, X::Size>>>
+) -> An<Binop<f64, FrameAdd<X::Size, f64>, MultiPass<X::Size, f64>, Constant<X::Size, f64>>>
 where
     X::Size: Size<f64> + Add<U0>,
     <X::Size as Add<U0>>::Output: Size<f64>,
 {
-    An(MultiPass::<f64, X::Size>::new()) + dc(x)
+    An(MultiPass::<X::Size, f64>::new()) + dc(x)
 }
 
 /// Subtract constant from signal.
 #[inline]
 pub fn sub<X: ConstantFrame<Sample = f64>>(
     x: X,
-) -> An<Binop<f64, FrameSub<f64, X::Size>, MultiPass<f64, X::Size>, Constant<f64, X::Size>>>
+) -> An<Binop<f64, FrameSub<X::Size, f64>, MultiPass<X::Size, f64>, Constant<X::Size, f64>>>
 where
     X::Size: Size<f64> + Add<U0>,
     <X::Size as Add<U0>>::Output: Size<f64>,
 {
-    An(MultiPass::<f64, X::Size>::new()) - dc(x)
+    An(MultiPass::<X::Size, f64>::new()) - dc(x)
 }
 
 /// Multiply signal with constant.
 #[inline]
 pub fn mul<X: ConstantFrame<Sample = f64>>(
     x: X,
-) -> An<Binop<f64, FrameMul<f64, X::Size>, MultiPass<f64, X::Size>, Constant<f64, X::Size>>>
+) -> An<Binop<f64, FrameMul<X::Size, f64>, MultiPass<X::Size, f64>, Constant<X::Size, f64>>>
 where
     X::Size: Size<f64> + Add<U0>,
     <X::Size as Add<U0>>::Output: Size<f64>,
 {
-    An(MultiPass::<f64, X::Size>::new()) * dc(x)
+    An(MultiPass::<X::Size, f64>::new()) * dc(x)
 }
 
 /// Butterworth lowpass filter (2nd order).
@@ -361,6 +399,34 @@ where
     An(Envelope::new(0.002, DEFAULT_SR, f))
 }
 
+/// Control envelope from time-varying, input dependent function `f(t, input)` with `t` in seconds.
+/// Spaces samples using pseudorandom jittering.
+/// Synonymous with `lfo2`.
+/// - Output(s): envelope linearly interpolated from samples at 2 ms intervals (average).
+#[inline]
+pub fn envelope2<E, R>(f: E) -> An<Envelope2<f64, f64, E, R>>
+where
+    E: Fn(f64, f64) -> R,
+    R: ConstantFrame<Sample = f64>,
+    R::Size: Size<f64>,
+{
+    An(Envelope2::new(0.002, DEFAULT_SR, f))
+}
+
+/// Control envelope from time-varying, input dependent function `f(t, value)` with `t` in seconds.
+/// Spaces samples using pseudorandom jittering.
+/// Synonymous with `envelope2`.
+/// - Output(s): envelope linearly interpolated from samples at 2 ms intervals (average).
+#[inline]
+pub fn lfo2<E, R>(f: E) -> An<Envelope2<f64, f64, E, R>>
+where
+    E: Fn(f64, f64) -> R,
+    R: ConstantFrame<Sample = f64>,
+    R::Size: Size<f64>,
+{
+    An(Envelope2::new(0.002, DEFAULT_SR, f))
+}
+
 /// Maximum Length Sequence noise generator from an `n`-bit sequence.
 /// - Output 0: repeating white noise sequence of only -1 and 1 values.
 #[inline]
@@ -391,22 +457,31 @@ pub fn white() -> An<Noise<f64>> {
     An(Noise::new())
 }
 
+/// FIR filter.
+/// - Input 0: signal.
+/// - Output 0: filtered signal.
+#[inline]
+pub fn fir<X: ConstantFrame<Sample = f64>>(weights: X) -> An<Fir<f64, X::Size>> {
+    An(Fir::new(weights))
+}
+
 /// Single sample delay.
 /// - Input 0: signal.
 /// - Output 0: delayed signal.
 #[inline]
-pub fn tick() -> An<Tick<f64, U1>> {
+pub fn tick() -> An<Tick<U1, f64>> {
     An(Tick::new(DEFAULT_SR))
 }
 
 /// Multichannel single sample delay.
 /// - Inputs: signal.
 /// - Outputs: delayed signal.
-pub fn multitick<N: Size<f64>>() -> An<Tick<f64, N>> {
+pub fn multitick<N: Size<f64>>() -> An<Tick<N, f64>> {
     An(Tick::new(convert(DEFAULT_SR)))
 }
 
 /// Fixed delay of `t` seconds.
+/// Delay time is rounded to the nearest sample.
 /// - Input 0: signal.
 /// - Output 0: delayed signal.
 #[inline]
@@ -414,19 +489,55 @@ pub fn delay(t: f64) -> An<Delay<f64>> {
     An(Delay::new(t, DEFAULT_SR))
 }
 
-/// Mix output of enclosed circuit `x` back to its input.
-/// Feedback circuit `x` must have an equal number of inputs and outputs.
+/// Tapped delay line with cubic interpolation.
+/// Minimum and maximum delay times are in seconds.
+/// - Input 0: signal.
+/// - Input 1: delay time in seconds.
+/// - Output 0: delayed signal.
+pub fn tap(min_delay: f64, max_delay: f64) -> An<Tap<U1, f64>> {
+    An(Tap::new(DEFAULT_SR, min_delay, max_delay))
+}
+
+/// Tapped delay line with cubic interpolation.
+/// The number of taps is `N`.
+/// Minimum and maximum delay times are in seconds.
+/// - Input 0: signal.
+/// - Inputs 1...N: delay time in seconds.
+/// - Output 0: delayed signal.
+pub fn multitap<N>(min_delay: f64, max_delay: f64) -> An<Tap<N, f64>>
+where
+    N: Size<f64> + Add<U1>,
+    <N as Add<U1>>::Output: Size<f64>,
+{
+    An(Tap::new(DEFAULT_SR, min_delay, max_delay))
+}
+
+/// 2x oversample enclosed `node`.
+/// - Inputs and outputs: from `node`.
+pub fn oversample<X>(node: An<X>) -> An<Oversampler<f64, X>>
+where
+    X: AudioNode<Sample = f64>,
+    X::Inputs: Size<f64>,
+    X::Outputs: Size<f64>,
+    X::Inputs: Size<Frame<f64, U128>>,
+    X::Outputs: Size<Frame<f64, U128>>,
+{
+    An(Oversampler::new(DEFAULT_SR, node.0))
+}
+
+/// Mix output of enclosed circuit `node` back to its input.
+/// Feedback circuit `node` must have an equal number of inputs and outputs.
 /// - Inputs: input signal.
-/// - Outputs: `x` output signal.
+/// - Outputs: `node` output signal.
 #[inline]
-pub fn feedback<X, N>(x: An<X>) -> An<Feedback<f64, X, N, FrameId<f64, N>>>
+pub fn feedback<N, X>(node: An<X>) -> An<Feedback<N, f64, X, FrameId<N, f64>>>
 where
     X: AudioNode<Sample = f64, Inputs = N, Outputs = N>,
     X::Inputs: Size<f64>,
     X::Outputs: Size<f64>,
     N: Size<f64>,
 {
-    An(Feedback::new(x.0, FrameId::new()))
+    An(Feedback::new(node.0, FrameId::new()))
 }
 
 /// Transform channels freely. Accounted as non-linear processing for signal flow.
@@ -485,15 +596,29 @@ pub fn shape(mode: Shape<f64>) -> An<Shaper<f64>> {
 }
 
 /// Clip signal to -1...1.
+#[inline]
 pub fn clip() -> An<Shaper<f64>> {
     super::prelude::clip()
 }
 
 /// Clip signal to min...max.
+#[inline]
 pub fn clip_to(minimum: f64, maximum: f64) -> An<Shaper<f64>> {
     super::prelude::clip_to(minimum, maximum)
 }
 
+/// Equal power mono-to-stereo panner.
+#[inline]
+pub fn panner() -> An<Panner<f64, U2>> {
+    An(Panner::new(0.0))
+}
+
+/// Fixed equal power mono-to-stereo panner with pan value in -1...1.
+#[inline]
+pub fn pan(pan: f64) -> An<Panner<f64, U1>> {
+    An(Panner::new(pan))
+}
+
 /// Parameter follower filter with halfway response time `t` seconds.
 #[inline]
 pub fn follow<S: ScalarOrPair<Sample = f64>>(t: S) -> An<AFollow<f64, f64, S>> {
@@ -529,7 +654,7 @@ pub fn pink() -> An<Pipe<f64, Noise<f64>, Pinkpass<f64, f64>>> {
 /// Brown noise.
 #[inline]
 pub fn brown() -> An<
-    Pipe<f64, Noise<f64>, Binop<f64, FrameMul<f64, U1>, Lowpole<f64, f64, U1>, Constant<f64, U1>>>,
+    Pipe<f64, Noise<f64>, Binop<f64, FrameMul<U1, f64>, Lowpole<f64, f64, U1>, Constant<U1, f64>>>,
 > {
     // Empirical normalization factor.
     white() >> lowpole_hz(10.0) * dc(13.7)
@@ -545,7 +670,7 @@ pub fn goertzel() -> An<Goertzel<f64, f64>> {
 #[inline]
 pub fn goertzel_hz(
     f: f64,
-) -> An<Pipe<f64, Stack<f64, Pass<f64>, Constant<f64, U1>>, Goertzel<f64, f64>>> {
+) -> An<Pipe<f64, Stack<f64, Pass<f64>, Constant<U1, f64>>, Goertzel<f64, f64>>> {
     super::prelude::goertzel_hz(f)
 }
 
@@ -556,7 +681,7 @@ pub fn goertzel_hz(
 /// - Inputs: input signal.
 /// - Outputs: `x` output signal.
 #[inline]
-pub fn fdn<X, N>(x: An<X>) -> An<Feedback<f64, X, N, FrameHadamard<f64, N>>>
+pub fn fdn<N, X>(x: An<X>) -> An<Feedback<N, f64, X, FrameHadamard<N, f64>>>
 where
     X: AudioNode<Sample = f64, Inputs = N, Outputs = N>,
     X::Inputs: Size<f64>,
@@ -568,7 +693,7 @@ where
 
 /// Bus `N` similar nodes from indexed generator `f`.
 #[inline]
-pub fn bus<N, X, F>(f: F) -> An<MultiBus<f64, N, X>>
+pub fn bus<N, X, F>(f: F) -> An<MultiBus<N, f64, X>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -583,7 +708,7 @@ where
 /// Bus `N` similar nodes from fractional generator `f`.
 /// The fractional generator is given values in the range 0...1.
 #[inline]
-pub fn busf<N, X, F>(f: F) -> An<MultiBus<f64, N, X>>
+pub fn busf<N, X, F>(f: F) -> An<MultiBus<N, f64, X>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -597,7 +722,7 @@ where
 
 /// Stack `N` similar nodes from indexed generator `f`.
 #[inline]
-pub fn stack<N, X, F>(f: F) -> An<MultiStack<f64, N, X>>
+pub fn stack<N, X, F>(f: F) -> An<MultiStack<N, f64, X>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -614,7 +739,7 @@ where
 /// Stack `N` similar nodes from fractional generator `f`.
 /// The fractional generator is given values in the range 0...1.
 #[inline]
-pub fn stackf<N, X, F>(f: F) -> An<MultiStack<f64, N, X>>
+pub fn stackf<N, X, F>(f: F) -> An<MultiStack<N, f64, X>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -630,7 +755,7 @@ where
 
 /// Branch into `N` similar nodes from indexed generator `f`.
 #[inline]
-pub fn branch<N, X, F>(f: F) -> An<MultiBranch<f64, N, X>>
+pub fn branch<N, X, F>(f: F) -> An<MultiBranch<N, f64, X>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -646,7 +771,7 @@ where
 /// Branch into `N` similar nodes from fractional generator `f`.
 /// The fractional generator is given values in the range 0...1.
 #[inline]
-pub fn branchf<N, X, F>(f: F) -> An<MultiBranch<f64, N, X>>
+pub fn branchf<N, X, F>(f: F) -> An<MultiBranch<N, f64, X>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -661,7 +786,7 @@ where
 
 /// Mix together `N` similar nodes from indexed generator `f`.
 #[inline]
-pub fn sum<N, X, F>(f: F) -> An<Reduce<f64, N, X, FrameAdd<f64, X::Outputs>>>
+pub fn sum<N, X, F>(f: F) -> An<Reduce<N, f64, X, FrameAdd<X::Outputs, f64>>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -677,7 +802,7 @@ where
 /// Mix together `N` similar nodes from fractional generator `f`.
 /// The fractional generator is given values in the range 0...1.
 #[inline]
-pub fn sumf<N, X, F>(f: F) -> An<Reduce<f64, N, X, FrameAdd<f64, X::Outputs>>>
+pub fn sumf<N, X, F>(f: F) -> An<Reduce<N, f64, X, FrameAdd<X::Outputs, f64>>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -692,7 +817,7 @@ where
 
 /// Chain together `N` similar nodes from indexed generator `f`.
 #[inline]
-pub fn pipe<N, X, F>(f: F) -> An<Chain<f64, N, X>>
+pub fn pipe<N, X, F>(f: F) -> An<Chain<N, f64, X>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -707,7 +832,7 @@ where
 /// Chain together `N` similar nodes from fractional generator `f`.
 /// The fractional generator is given values in the range 0...1.
 #[inline]
-pub fn pipef<N, X, F>(f: F) -> An<Chain<f64, N, X>>
+pub fn pipef<N, X, F>(f: F) -> An<Chain<N, f64, X>>
 where
     N: Size<f64>,
     N: Size<X>,
@@ -721,43 +846,43 @@ where
 
 /// Split signal into N channels.
 #[inline]
-pub fn split<N>() -> An<Split<f64, N>>
+pub fn split<N>() -> An<Split<N, f64>>
 where
     N: Size<f64>,
 {
-    super::prelude::split::<f64, N>()
+    super::prelude::split::<N, f64>()
 }
 
 /// Split M channels into N branches. The output has M * N channels.
 #[inline]
-pub fn multisplit<M, N>() -> An<MultiSplit<f64, M, N>>
+pub fn multisplit<M, N>() -> An<MultiSplit<M, N, f64>>
 where
     M: Size<f64> + Mul<N>,
     N: Size<f64>,
     <M as Mul<N>>::Output: Size<f64>,
 {
-    super::prelude::multisplit::<f64, M, N>()
+    super::prelude::multisplit::<M, N, f64>()
 }
 
 /// Average N channels into one. Inverse of `split`.
 #[inline]
-pub fn join<N>() -> An<Join<f64, N>>
+pub fn join<N>() -> An<Join<N, f64>>
 where
     N: Size<f64>,
 {
-    super::prelude::join::<f64, N>()
+    super::prelude::join::<N, f64>()
 }
 
 /// Average `N` branches of `M` channels into one branch with `M` channels.
 /// The input has `M` * `N` channels. Inverse of `multisplit::<M, N>`.
 #[inline]
-pub fn multijoin<M, N>() -> An<MultiJoin<f64, M, N>>
+pub fn multijoin<M, N>() -> An<MultiJoin<M, N, f64>>
 where
     M: Size<f64> + Mul<N>,
     N: Size<f64>,
     <M as Mul<N>>::Output: Size<f64>,
 {
-    super::prelude::multijoin::<f64, M, N>()
+    super::prelude::multijoin::<M, N, f64>()
 }
 
 /// Stereo reverb.
@@ -775,12 +900,13 @@ pub fn reverb_stereo(
                 f64,
                 Pipe<
                     f64,
-                    MultiSplit<f64, U2, U16>,
+                    MultiSplit<U2, U16, f64>,
                     Feedback<
+                        U32,
                         f64,
                         MultiStack<
-                            f64,
                             U32,
+                            f64,
                             Pipe<
                                 f64,
                                 Pipe<
@@ -790,21 +916,20 @@ pub fn reverb_stereo(
                                 >,
                                 Binop<
                                     f64,
-                                    FrameMul<f64, U1>,
-                                    MultiPass<f64, U1>,
-                                    Constant<f64, U1>,
+                                    FrameMul<U1, f64>,
+                                    MultiPass<U1, f64>,
+                                    Constant<U1, f64>,
                                 >,
                             >,
                         >,
-                        U32,
-                        FrameHadamard<f64, U32>,
+                        FrameHadamard<U32, f64>,
                     >,
                 >,
-                MultiJoin<f64, U2, U16>,
+                MultiJoin<U2, U16, f64>,
             >,
-            Binop<f64, FrameMul<f64, U2>, MultiPass<f64, U2>, Constant<f64, U2>>,
+            Binop<f64, FrameMul<U2, f64>, MultiPass<U2, f64>, Constant<U2, f64>>,
         >,
-        Binop<f64, FrameMul<f64, U2>, MultiPass<f64, U2>, Constant<f64, U2>>,
+        Binop<f64, FrameMul<U2, f64>, MultiPass<U2, f64>, Constant<U2, f64>>,
     >,
 > {
     super::prelude::reverb_stereo::<f64, f64>(wet, time)
@@ -831,21 +956,21 @@ pub fn triangle() -> An<WaveSynth<'static, f64, U1>> {
 /// Fixed saw wave oscillator at `f` Hz.
 /// - Output 0: saw wave
 #[inline]
-pub fn saw_hz(f: f64) -> An<Pipe<f64, Constant<f64, U1>, WaveSynth<'static, f64, U1>>> {
+pub fn saw_hz(f: f64) -> An<Pipe<f64, Constant<U1, f64>, WaveSynth<'static, f64, U1>>> {
     super::prelude::saw_hz(f)
 }
 
 /// Fixed square wave oscillator at `f` Hz.
 /// - Output 0: square wave
 #[inline]
-pub fn square_hz(f: f64) -> An<Pipe<f64, Constant<f64, U1>, WaveSynth<'static, f64, U1>>> {
+pub fn square_hz(f: f64) -> An<Pipe<f64, Constant<U1, f64>, WaveSynth<'static, f64, U1>>> {
     super::prelude::square_hz(f)
 }
 
 /// Fixed triangle wave oscillator at `f` Hz.
 /// - Output 0: triangle wave
 #[inline]
-pub fn triangle_hz(f: f64) -> An<Pipe<f64, Constant<f64, U1>, WaveSynth<'static, f64, U1>>> {
+pub fn triangle_hz(f: f64) -> An<Pipe<f64, Constant<U1, f64>, WaveSynth<'static, f64, U1>>> {
     super::prelude::triangle_hz(f)
 }
 
@@ -874,7 +999,7 @@ pub fn lowpass_hz(f: f64, q: f64) -> An<FixedSvf<f64, f64, LowpassMode<f64>>> {
 #[inline]
 pub fn lowpass_q(
     q: f64,
-) -> An<Pipe<f64, Stack<f64, MultiPass<f64, U2>, Constant<f64, U1>>, Svf<f64, f64, LowpassMode<f64>>>>
+) -> An<Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U1, f64>>, Svf<f64, f64, LowpassMode<f64>>>>
 {
     super::prelude::lowpass_q::<f64, f64>(q)
 }
@@ -905,7 +1030,7 @@ pub fn highpass_hz(f: f64, q: f64) -> An<FixedSvf<f64, f64, HighpassMode<f64>>>
 pub fn highpass_q(
     q: f64,
 ) -> An<
-    Pipe<f64, Stack<f64, MultiPass<f64, U2>, Constant<f64, U1>>, Svf<f64, f64, HighpassMode<f64>>>,
+    Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U1, f64>>, Svf<f64, f64, HighpassMode<f64>>>,
 > {
     super::prelude::highpass_q::<f64, f64>(q)
 }
@@ -936,7 +1061,7 @@ pub fn bandpass_hz(f: f64, q: f64) -> An<FixedSvf<f64, f64, BandpassMode<f64>>>
 pub fn bandpass_q(
     q: f64,
 ) -> An<
-    Pipe<f64, Stack<f64, MultiPass<f64, U2>, Constant<f64, U1>>, Svf<f64, f64, BandpassMode<f64>>>,
+    Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U1, f64>>, Svf<f64, f64, BandpassMode<f64>>>,
 > {
     super::prelude::bandpass_q::<f64, f64>(q)
 }
@@ -966,7 +1091,7 @@ pub fn notch_hz(f: f64, q: f64) -> An<FixedSvf<f64, f64, NotchMode<f64>>> {
 #[inline]
 pub fn notch_q(
     q: f64,
-) -> An<Pipe<f64, Stack<f64, MultiPass<f64, U2>, Constant<f64, U1>>, Svf<f64, f64, NotchMode<f64>>>>
+) -> An<Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U1, f64>>, Svf<f64, f64, NotchMode<f64>>>>
 {
     super::prelude::notch_q::<f64, f64>(q)
 }
@@ -996,7 +1121,7 @@ pub fn peak_hz(f: f64, q: f64) -> An<FixedSvf<f64, f64, PeakMode<f64>>> {
 #[inline]
 pub fn peak_q(
     q: f64,
-) -> An<Pipe<f64, Stack<f64, MultiPass<f64, U2>, Constant<f64, U1>>, Svf<f64, f64, PeakMode<f64>>>>
+) -> An<Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U1, f64>>, Svf<f64, f64, PeakMode<f64>>>>
 {
     super::prelude::peak_q::<f64, f64>(q)
 }
@@ -1026,7 +1151,7 @@ pub fn allpass_hz(f: f64, q: f64) -> An<FixedSvf<f64, f64, AllpassMode<f64>>> {
 #[inline]
 pub fn allpass_q(
     q: f64,
-) -> An<Pipe<f64, Stack<f64, MultiPass<f64, U2>, Constant<f64, U1>>, Svf<f64, f64, AllpassMode<f64>>>>
+) -> An<Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U1, f64>>, Svf<f64, f64, AllpassMode<f64>>>>
 {
     super::prelude::allpass_q::<f64, f64>(q)
 }
@@ -1058,7 +1183,7 @@ pub fn bell_hz(f: f64, q: f64, gain: f64) -> An<FixedSvf<f64, f64, BellMode<f64>
 pub fn bell_q(
     q: f64,
     gain: f64,
-) -> An<Pipe<f64, Stack<f64, MultiPass<f64, U2>, Constant<f64, U2>>, Svf<f64, f64, BellMode<f64>>>>
+) -> An<Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U2, f64>>, Svf<f64, f64, BellMode<f64>>>>
 {
     super::prelude::bell_q::<f64, f64>(q, gain)
 }
@@ -1091,7 +1216,7 @@ pub fn lowshelf_q(
     q: f64,
     gain: f64,
 ) -> An<
-    Pipe<f64, Stack<f64, MultiPass<f64, U2>, Constant<f64, U2>>, Svf<f64, f64, LowshelfMode<f64>>>,
+    Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U2, f64>>, Svf<f64, f64, LowshelfMode<f64>>>,
 > {
     super::prelude::lowshelf_q::<f64, f64>(q, gain)
 }
@@ -1124,7 +1249,7 @@ pub fn highshelf_q(
     q: f64,
     gain: f64,
 ) -> An<
-    Pipe<f64, Stack<f64, MultiPass<f64, U2>, Constant<f64, U2>>, Svf<f64, f64, HighshelfMode<f64>>>,
+    Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U2, f64>>, Svf<f64, f64, HighshelfMode<f64>>>,
 > {
     super::prelude::highshelf_q::<f64, f64>(q, gain)
 }
