@@ -5,37 +5,34 @@ use super::math::*;
 use super::signal::*;
 use super::*;
 use numeric_array::*;
-use std::marker::PhantomData;
 
 /// Sine oscillator.
-pub struct Sine<T: Float> {
-    _marker: PhantomData<T>,
-    phase: f64,
-    sample_duration: f64,
+pub struct Sine<T: Real> {
+    phase: T,
+    sample_duration: T,
     hash: u64,
 }
 
-impl<T: Float> Sine<T> {
+impl<T: Real> Sine<T> {
     pub fn new(sample_rate: f64) -> Sine<T> {
         Sine {
-            _marker: PhantomData,
-            phase: 0.0,
-            sample_duration: 1.0 / sample_rate,
+            phase: T::zero(),
+            sample_duration: T::from_f64(1.0 / sample_rate),
             hash: 0,
         }
     }
 }
 
-impl<T: Float> AudioNode for Sine<T> {
+impl<T: Real> AudioNode for Sine<T> {
     const ID: u64 = 21;
     type Sample = T;
     type Inputs = typenum::U1;
     type Outputs = typenum::U1;
 
     fn reset(&mut self, sample_rate: Option<f64>) {
-        self.phase = rnd(self.hash as i64);
+        self.phase = T::from_f64(rnd(self.hash as i64));
         if let Some(sr) = sample_rate {
-            self.sample_duration = 1.0 / sr
+            self.sample_duration = T::from_f64(1.0 / sr);
         };
     }
 
@@ -44,9 +41,21 @@ impl<T: Float> AudioNode for Sine<T> {
         &mut self,
         input: &Frame<Self::Sample, Self::Inputs>,
     ) -> Frame<Self::Sample, Self::Outputs> {
-        let frequency = input[0].to_f64();
-        self.phase = (self.phase + frequency * self.sample_duration).fract();
-        [convert(sin(self.phase * TAU))].into()
+        self.phase = (self.phase + input[0] * self.sample_duration).fract();
+        [sin(self.phase * T::from_f64(TAU))].into()
+    }
+
+    fn process(
+        &mut self,
+        size: usize,
+        input: &[&[Self::Sample]],
+        output: &mut [&mut [Self::Sample]],
+    ) {
+        for i in 0..size {
+            self.phase += input[0][i] * self.sample_duration;
+            output[0][i] = sin(self.phase * T::from_f64(TAU));
+        }
+        self.phase = self.phase.fract();
     }
 
     #[inline]
